@@ -49,6 +49,8 @@ def get_track_type(format):
         "bed": "annotation",
         "refgene": "annotation",
         "bcf": "variant",
-        "vcf": "variant"
+        "vcf": "variant",
+        "wig": "wig",
+        "bedgraph": "wig"
     }
     return dict[format]
